@@ -1,7 +1,8 @@
 library(diveMove)
 
 (sealX <- readTDR(system.file(file.path("data", "dives.csv"),
-                              package="diveMove"), concurrentCols=4:6))
+                              package="diveMove"), concurrentCols=4:6,
+                  sep=";", na.strings="", as.is=TRUE))
 (dcalib <- calibrateDepth(sealX, offset=3))
 tdrstats <- diveStats(dcalib)
 head(tdrstats)
@@ -11,7 +12,8 @@ head(stamps <- stampDive(dcalib))
 
 (sealX <- readTDR(system.file(file.path("data", "dives.csv"),
                               package="diveMove"),
-                  speed=TRUE, concurrentCols=4:6))
+                  speed=TRUE, concurrentCols=4:6,
+                  sep=";", na.strings="", as.is=TRUE))
 (dcalib <- calibrateDepth(sealX, offset=3))
 (vcalib <- calibrateSpeed(dcalib, z=1))
 tdrstats <- diveStats(vcalib)
@@ -19,3 +21,9 @@ head(tdrstats)
 head(stamps <- stampDive(vcalib))
 (att <- timeBudget(vcalib, FALSE))
 (att <- timeBudget(vcalib, TRUE))
+
+
+###_ + Emacs local variables
+## Local variables:
+## allout-layout: (+ : 0)
+## End:
